@@ -93,10 +93,10 @@ class TestComplianceValid(TestCase):
     """Test the compliance with the standard test suites for
         valid toml files here:
 
-        %(url)s
+    %(url)s
 
-    The tests come up with a JSON counterpart that can be used to valid whether
-    loading the toml file yields the same result as the JSON counterpart.
+The tests come up with a JSON counterpart that can be used to valid whether
+loading the toml file yields the same result as the JSON counterpart.
     """
 
     ORDER = 1
@@ -148,18 +148,23 @@ class TestComplianceInValidDummy(TestComplianceDummy):
     def result(self, out: Any) -> str:
         replace_newline = lambda s: s.replace("\n", " ")
         passed = [isinstance(e, Exception) for e in out]
+        failed = [e for e in out if not isinstance(e, Exception)]
         if all(passed):
             return (
                 f"OK: {replace_newline(str(out[-1]))}<br /> "
                 f"*{len(passed)}/{len(passed)} (100%) passed*"
             )
-        out.append(
+
+        if len(failed) > 10:
+            failed = failed[:10] + [
+                f"Not OK: *{len(failed) - 10} more items incorrectly parsed.*"
+            ]
+
+        failed.append(
             f"*{sum(passed)}/{self.total} "
             f"({100.0 * sum(passed) / self.total:.2f}%) passed*"
         )
-        return "<br />".join(
-            replace_newline(e) for e in out if isinstance(e, str)
-        )
+        return "<br />".join(replace_newline(str(e)) for e in failed)
 
 
 @doc_formatter(url=TOML_TEST_REPO)
@@ -167,11 +172,11 @@ class TestComplianceInvalid(TestComplianceValid):
     """Test the compliance with the standard test suites for
         invalid toml files here:
 
-        %(url)s
+    %(url)s
 
-    - `Not OK`: The toml file is parsed without error, but expected to fail.
-    - `OK`: All files are failed to parse, as expected. Showing the last parsing
-        error.
+- `Not OK`: The toml file is parsed without error, but expected to fail.
+- `OK`: All files are failed to parse, as expected. Showing the last parsing
+    error.
     """
 
     ORDER = 2
